@@ -21,7 +21,10 @@ def ignore_import_warnings_for_related_fields(orig_method, self, node):
     form 'from django.db.models import OneToOneField' raise an unused-import
     warning
     """
-    to_consume = self._to_consume[0]
+    to_consume = self._to_consume[0]  # pylint: disable=W0212
+    # we can disable this warning ('Access to a protected member _to_consume of a client class')
+    # as it's not actually a client class, but rather, this method is being monkey patched
+    # onto the class and so the access is valid
 
     new_things = {}
 
@@ -33,7 +36,7 @@ def ignore_import_warnings_for_related_fields(orig_method, self, node):
         new_things[name] = stmts
 
     new_consume = (new_things,) + to_consume[1:]
-    self._to_consume = [new_consume]
+    self._to_consume = [new_consume]  # pylint: disable=W0212
 
     return orig_method(self, node)
 
@@ -190,13 +193,13 @@ def is_model_view_subclass_method_shouldnt_be_function(node):
     while parent and not isinstance(parent, ScopedClass):
         parent = parent.parent
 
-    #subclass = 'django.views.generic.base.View'
     subclass = '.View'
     return parent is not None and parent.name.endswith('View') and node_is_subclass(parent, subclass)
 
 
 def is_model_view_subclass_unused_argument(node):
-    """Checks that node is get or post method of the View class and it has valid arguments.
+    """
+    Checks that node is get or post method of the View class and it has valid arguments.
 
     TODO: Bad checkings, need to be more smart.
     """
@@ -310,9 +313,17 @@ def apply_augmentations(linter):
     suppress_message(linter, ClassChecker.visit_class, 'W0232', is_model_media_subclass)
     suppress_message(linter, MisdesignChecker.leave_class, 'R0903', is_model_media_subclass)
 
+    # Too few public methods started appearing for Views and Models as part of Pylint>=1.4 / astroid>=1.3.3
+    # Not sure why, suspect this is a failure to get the parent classes somewhere
+    # For now, just suppress it on models and views
+    suppress_message(linter, MisdesignChecker.leave_class, 'R0903', is_class('django.db.models.base.Model'))
+    # TODO: why does this not work with the fqn of 'View'? Must be something to do with the overriding and transforms
+    suppress_message(linter, MisdesignChecker.leave_class, 'R0903', is_class('.View'))
+
     # Admin
     # Too many public methods (40+/20)
-    # TODO: Count public methods of django.contrib.admin.options.ModelAdmin and increase MisdesignChecker.config.max_public_methods to this value to count only user' methods.
+    # TODO: Count public methods of django.contrib.admin.options.ModelAdmin and increase
+    # MisdesignChecker.config.max_public_methods to this value to count only user' methods.
     #nb_public_methods = 0
     #for method in node.methods():
     #    if not method.name.startswith('_'):
@@ -323,8 +334,10 @@ def apply_augmentations(linter):
     suppress_message(linter, MisdesignChecker.leave_class, 'R0904', is_model_test_case_subclass)
 
     # View
-    suppress_message(linter, ClassChecker.leave_function, 'R0201', is_model_view_subclass_method_shouldnt_be_function)  # Method could be a function (get, post)
-    suppress_message(linter, VariablesChecker.leave_function, 'W0613', is_model_view_subclass_unused_argument)  # Unused argument 'request' (get, post)
+    # Method could be a function (get, post)
+    suppress_message(linter, ClassChecker.leave_function, 'R0201', is_model_view_subclass_method_shouldnt_be_function)
+    # Unused argument 'request' (get, post)
+    suppress_message(linter, VariablesChecker.leave_function, 'W0613', is_model_view_subclass_unused_argument)
 
     # django-mptt
     suppress_message(linter, DocStringChecker.visit_class, 'C0111', is_model_mpttmeta_subclass)
