@@ -1,5 +1,6 @@
 """Models."""
-from astroid.nodes import Assign, Function, AssName
+from astroid import Const
+from astroid.nodes import Assign, Function, AssName, Class
 from pylint.interfaces import IAstroidChecker
 from pylint.checkers.utils import check_messages
 from pylint.checkers import BaseChecker
@@ -25,6 +26,24 @@ MESSAGES = {
 }
 
 
+def _is_meta_with_abstract(node):
+    if isinstance(node, Class) and node.name == 'Meta':
+        for meta_child in node.get_children():
+            if not isinstance(meta_child, Assign):
+                continue
+            if not meta_child.targets[0].name == 'abstract':
+                continue
+            if not isinstance(meta_child.value, Const):
+                continue
+                # TODO: handle tuple assignment?
+            # eg:
+            #    abstract, something_else = True, 1
+            if meta_child.value.value:
+                # this class is abstract
+                return True
+    return False
+
+
 class ModelChecker(BaseChecker):
     """Django model checker."""
     __implements__ = IAstroidChecker
@@ -40,6 +59,9 @@ class ModelChecker(BaseChecker):
             return
 
         for child in node.get_children():
+            if _is_meta_with_abstract(child):
+                return
+
             if isinstance(child, Assign):
                 grandchildren = list(child.get_children())
 
