@@ -1,8 +1,12 @@
 
 import os
 import unittest
+from django.conf import settings
 from logilab.common import testlib
-from pylint.testutils import make_tests, LintTestUsingModule, LintTestUsingFile, cb_test_gen, linter
+from pylint.testutils import make_tests, LintTestUsingFile, cb_test_gen, linter
+
+
+settings.configure()
 
 
 HERE = os.path.dirname(os.path.abspath(__file__))
@@ -13,7 +17,7 @@ linter.global_set_option('required-attributes', ())  # remove required __revisio
 
 
 def tests():
-    callbacks = [cb_test_gen(LintTestUsingModule), cb_test_gen(LintTestUsingFile)]
+    callbacks = [cb_test_gen(LintTestUsingFile)]
 
     input_dir = os.path.join(HERE, 'input')
     messages_dir = os.path.join(HERE, 'messages')
